/* src/math1/fnclib/rexp.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     REXP */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
doublereal rexp_(real *rx, integer *ib, integer *ie)
{
    /* System generated locals */
    integer i__1;
    real ret_val;

    /* Local variables */
    static integer i__;
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);

    if (*ib == 0) {
	msgdmp_("E", "REXP  ", "IB .EQ. 0.", (ftnlen)1, (ftnlen)6, (ftnlen)10)
		;
    }
    ret_val = *rx;
    i__1 = abs(*ie);
    for (i__ = 1; i__ <= i__1; ++i__) {
	if (*ie > 0) {
	    ret_val *= *ib;
	} else {
	    ret_val /= *ib;
	}
/* L10: */
    }
    return ret_val;
} /* rexp_ */

